@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '1.072';
-use BZ::Client::XMLRPC();
-use HTTP::Cookies();
+$BZ::Client::VERSION = '2.0_1';
+use BZ::Client::XMLRPC;
+use BZ::Client::Exception;
+use HTTP::CookieJar;
 
 sub new {
     my $class = shift;
@@ -71,7 +72,6 @@ sub autologin {
 
 sub error {
     my ( $self, $message, $http_code, $xmlrpc_code ) = @_;
-    require BZ::Client::Exception;
     BZ::Client::Exception->throw(
         message     => $message,
         http_code   => $http_code,
@@ -131,9 +131,10 @@ sub xmlrpc {
 
 sub login {
     my $self = shift;
-    my $rl = BZ::Client::XMLRPC::boolean->new($self->{'restrictlogin'} ? 1 : 0);
+    my $rl = $self->{'restrictlogin'} ? BZ::Client::XMLRPC::boolean->TRUE
+                                      : BZ::Client::XMLRPC::boolean->FALSE;
     my %params = (
-        'remember'       => BZ::Client::XMLRPC::boolean->new(0), # dropped in 4.4 as cookies no longer used
+        'remember'       => BZ::Client::XMLRPC::boolean->FALSE, # dropped in 4.4 as cookies no longer used
         'restrictlogin'  => $rl, # added in 3.6
         'restrict_login' => $rl, # added in 4.4 for tokens
     );
@@ -150,7 +151,7 @@ sub login {
         $params{password} = $password;
         $self->log( 'debug', 'BZ::Client::login, going to log in with username and password' );
     }
-    my $cookies = HTTP::Cookies->new();
+    my $cookies = HTTP::CookieJar->new();
     my $response = $self->_api_call( 'User.login', \%params, $cookies );
     if ( not defined( $response->{'id'} )
         or $response->{'id'} !~ m/^\d+$/s )
@@ -181,7 +182,8 @@ sub logout {
             if $self->{'token'};
         $self->xmlrpc->request( 'methodName' => 'User.logout', params => [$params] );
         $cookies->clear() if $cookies;
-        $self->{'token'} = undef;
+        delete $self->{'token'};
+        delete $self->{'cookies'};
     }
     return 1
 }
@@ -212,7 +214,7 @@ sub _api_call {
     my $xmlrpc = $self->xmlrpc();
 
     if ($cookies) {
-        $xmlrpc->user_agent->cookie_jar($cookies);
+        $xmlrpc->web_agent->{cookie_jar} = $cookies;
     }
     $params->{token} = $self->{'token'}
         if ($self->{'token'} and not $params->{token});
@@ -248,7 +250,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 SYNOPSIS
 
@@ -259,6 +261,16 @@ version 1.072
                                 );
   $client->login();
 
+=head1 WARNING
+
+USE THIS 2.0 DEVELOPMENT VERSION AT YOUR OWN RISK!
+
+(Which is actually, a clausing in the open source license this software is provided under)
+
+THE API IS CHANGING, STUFF IS BREAKING, YMMV!
+
+USE THE 1.x SERIES UNLESS YOU PREFER DEBUGGING TO GETTING THINGS DONE.
+
 =head1 CLASS METHODS
 
 This section lists the class methods of BZ::Client.
@@ -290,8 +302,24 @@ The Bugzilla servers URL, for example C<https://bugzilla.mozilla.org/>.
 
 API keys were introduced in 5.0.
 
-You can set up an API key by using the 'API Key' tab in the Preferences
-pages in your Bugzilla install.
+An API Key can be obtained in the web interface of your Bugzilla server,
+with the following steps:
+
+=over 4
+
+=item Click 'Preferences' link
+
+=item Click 'API Keys' tab
+
+=item Click the checkbox next to 'Generate a new API key...'
+
+=item If you like, add some description in the textbox
+
+=item Click the 'Submit Changes' button
+
+=item Key appears in the table under the 'Existing API keys' subheading
+
+=back
 
 =item user
 
