@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '1.072';
-use BZ::Client::API();
+$BZ::Client::Bugzilla::VERSION = '2.0_1';
+use BZ::Client::API;
 
 our @ISA = qw(BZ::Client::API);
 
@@ -46,7 +46,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -54,7 +54,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 SYNOPSIS
 
@@ -115,7 +115,7 @@ Returns the Bugzilla servers version.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Bugzilla.html>
 
 =head1 AUTHORS
 
