@@ -6,11 +6,13 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '1.072';
-use BZ::Client::API();
+$BZ::Client::Product::VERSION = '2.0_1';
+use BZ::Client::API;
 
 our @ISA = qw(BZ::Client::API);
 
+# See https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Product.html
+
 sub get_selectable_products {
     my($class, $client) = @_;
     $client->log('debug', 'BZ::Client::Product::get_selectable_products: Asking');
@@ -111,7 +113,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -119,7 +121,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 SYNOPSIS
 
@@ -197,7 +199,7 @@ Gets or sets the products description.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Product.html>
 
 =head1 AUTHORS
 
