@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Test;
-$BZ::Client::Test::VERSION = '1.072';
-use BZ::Client();
+$BZ::Client::Test::VERSION = '2.0_1';
+use BZ::Client;
 
 sub new {
     my $class = shift;
@@ -97,7 +97,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -105,7 +105,7 @@ BZ::Client::Test - Module for writing integration tests
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 SYNOPSIS
 
