@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '1.072';
-use BZ::Client::API();
+$BZ::Client::User::VERSION = '2.0_1';
+use BZ::Client::API;
 
 our @ISA = qw(BZ::Client::API);
 
@@ -92,7 +92,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -100,7 +100,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 SYNOPSIS
 
@@ -479,7 +479,7 @@ Logged-in users are not authorized to edit other users.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/User.html>
 
 =head1 AUTHORS
 
