@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Array;
-$BZ::Client::XMLRPC::Array::VERSION = '1.072';
-use BZ::Client::XMLRPC::Handler ();
+$BZ::Client::XMLRPC::Array::VERSION = '2.0_1';
+use BZ::Client::XMLRPC::Handler;
 
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
@@ -65,7 +65,7 @@ BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 AUTHORS
 
