@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '1.072';
-use BZ::Client::XMLRPC::Response ();
+$BZ::Client::XMLRPC::Parser::VERSION = '2.0_1';
+use BZ::Client::XMLRPC::Response;
 use XML::Parser ();
 
 sub new {
@@ -105,7 +105,7 @@ BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 AUTHORS
 
