@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Response;
-$BZ::Client::XMLRPC::Response::VERSION = '1.072';
-use BZ::Client::XMLRPC::Handler ();
-use BZ::Client::XMLRPC::Value ();
+$BZ::Client::XMLRPC::Response::VERSION = '2.0_1';
+use BZ::Client::XMLRPC::Handler;
+use BZ::Client::XMLRPC::Value;
 
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
@@ -105,7 +105,7 @@ BZ::Client::XMLRPC::Response - Event handler for parsing an XML-RPC response.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 AUTHORS
 
