@@ -6,8 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Struct;
-$BZ::Client::XMLRPC::Struct::VERSION = '1.072';
-use BZ::Client::XMLRPC::Handler ();
+$BZ::Client::XMLRPC::Struct::VERSION = '2.0_1';
+use BZ::Client::XMLRPC::Handler;
 
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
@@ -89,7 +89,7 @@ BZ::Client::XMLRPC::Struct - Event handler for parsing a single XML-RPC struct.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 AUTHORS
 
