@@ -6,10 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Value;
-$BZ::Client::XMLRPC::Value::VERSION = '1.072';
-use BZ::Client::XMLRPC::Handler ();
-use BZ::Client::XMLRPC::Struct ();
-use BZ::Client::XMLRPC::Array ();
+$BZ::Client::XMLRPC::Value::VERSION = '2.0_1';
+use BZ::Client::XMLRPC::Handler;
+use BZ::Client::XMLRPC::Struct;
+use BZ::Client::XMLRPC::Array;
 use DateTime::Format::ISO8601 ();
 
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
@@ -138,7 +138,7 @@ BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
 
 =head1 VERSION
 
-version 1.072
+version 2.0_1
 
 =head1 AUTHORS
 
